dose_resp_ind: Extract the information from the simulation data frame to...

Description Usage Arguments Value

View source: R/dose_resp_ind.r

Description

Extract the information from the simulation data frame to analyse the dose response effects

Usage

1
dose_resp_ind(allsim, dataset, dr = seq(0, 1, 0.1))

Arguments

allsim

dataset with all simulations values

dataset

dataset with all variables

dr

a vector with dose response values

Value

a data frame with dose response values


itamuria/expose documentation built on Aug. 10, 2020, 9:15 a.m.